@@ -14,35 +14,57 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Dict, List, Optional, Union
+from __future__ import annotations
 
+from typing import Any
+
+from azure.identity import DefaultAzureCredential
 from azure.servicebus import ServiceBusClient, ServiceBusMessage, ServiceBusSender
 from azure.servicebus.management import QueueProperties, ServiceBusAdministrationClient
 
 from airflow.hooks.base import BaseHook
+from airflow.providers.microsoft.azure.utils import get_field
 
 
 class BaseAzureServiceBusHook(BaseHook):
     """
-    BaseAzureServiceBusHook class to create session and create connection using connection string
+    BaseAzureServiceBusHook class to create session and create connection using connection string.
 
     :param azure_service_bus_conn_id: Reference to the
         :ref:`Azure Service Bus connection<howto/connection:azure_service_bus>`.
     """
 
-    conn_name_attr = 'azure_service_bus_conn_id'
-    default_conn_name = 'azure_service_bus_default'
-    conn_type = 'azure_service_bus'
-    hook_name = 'Azure Service Bus'
+    conn_name_attr = "azure_service_bus_conn_id"
+    default_conn_name = "azure_service_bus_default"
+    conn_type = "azure_service_bus"
+    hook_name = "Azure Service Bus"
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict[str, Any]:
-        """Returns custom field behaviour"""
+    def get_connection_form_widgets() -> dict[str, Any]:
+        """Returns connection widgets to add to connection form."""
+        from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
+        from flask_babel import lazy_gettext
+        from wtforms import PasswordField, StringField
+
         return {
-            "hidden_fields": ['port', 'host', 'extra', 'login', 'password'],
-            "relabeling": {'schema': 'Connection String'},
+            "fully_qualified_namespace": StringField(
+                lazy_gettext("Fully Qualified Namespace"), widget=BS3TextFieldWidget()
+            ),
+            "credential": PasswordField(lazy_gettext("Credential"), widget=BS3TextFieldWidget()),
+        }
+
+    @staticmethod
+    def get_ui_field_behaviour() -> dict[str, Any]:
+        """Returns custom field behaviour."""
+        return {
+            "hidden_fields": ["port", "host", "extra", "login", "password"],
+            "relabeling": {"schema": "Connection String"},
             "placeholders": {
-                'schema': 'Endpoint=sb://<Resource group>.servicebus.windows.net/;SharedAccessKeyName=<AccessKeyName>;SharedAccessKey=<SharedAccessKey>',  # noqa
+                "fully_qualified_namespace": (
+                    "<Resource group>.servicebus.windows.net (for Azure AD authenticaltion)"
+                ),
+                "credential": "credential",
+                "schema": "Endpoint=sb://<Resource group>.servicebus.windows.net/;SharedAccessKeyName=<AccessKeyName>;SharedAccessKey=<SharedAccessKey>",  # noqa
             },
         }
 
@@ -53,24 +75,44 @@ class BaseAzureServiceBusHook(BaseHook):
     def get_conn(self):
         raise NotImplementedError
 
+    def _get_field(self, extras: dict, field_name: str) -> str:
+        return get_field(
+            conn_id=self.conn_id,
+            conn_type=self.conn_type,
+            extras=extras,
+            field_name=field_name,
+        )
+
 
 class AdminClientHook(BaseAzureServiceBusHook):
-    """
-    Interacts with ServiceBusAdministrationClient client
-    to create, update, list, and delete resources of a
-    Service Bus namespace.  This hook uses the same Azure Service Bus client connection inherited
-    from the base class
+    """Interact with the ServiceBusAdministrationClient.
+
+    This can create, update, list, and delete resources of a Service Bus
+    namespace. This hook uses the same Azure Service Bus client connection
+    inherited from the base class.
     """
 
     def get_conn(self) -> ServiceBusAdministrationClient:
-        """
-        Create and returns ServiceBusAdministrationClient by using the connection
-        string in connection details
+        """Create a ServiceBusAdministrationClient instance.
+
+        This uses the connection string in connection details.
         """
         conn = self.get_connection(self.conn_id)
-
         connection_string: str = str(conn.schema)
-        return ServiceBusAdministrationClient.from_connection_string(connection_string)
+        if connection_string:
+            client = ServiceBusAdministrationClient.from_connection_string(connection_string)
+        else:
+            extras = conn.extra_dejson
+            credential: str | DefaultAzureCredential = self._get_field(extras=extras, field_name="credential")
+            fully_qualified_namespace = self._get_field(extras=extras, field_name="fully_qualified_namespace")
+            if not credential:
+                credential = DefaultAzureCredential()
+            client = ServiceBusAdministrationClient(
+                fully_qualified_namespace=fully_qualified_namespace,
+                credential=credential,  # type: ignore[arg-type]
+            )
+        self.log.info("Create and returns ServiceBusAdministrationClient")
+        return client
 
     def create_queue(
         self,
@@ -80,7 +122,7 @@ class AdminClientHook(BaseAzureServiceBusHook):
         enable_batched_operations: bool = True,
     ) -> QueueProperties:
         """
-        Create Queue by connecting to service Bus Admin client return the QueueProperties
+        Create Queue by connecting to service Bus Admin client return the QueueProperties.
 
         :param queue_name: The name of the queue or a QueueProperties with name.
         :param max_delivery_count: The maximum delivery count. A message is automatically
@@ -104,7 +146,7 @@ class AdminClientHook(BaseAzureServiceBusHook):
 
     def delete_queue(self, queue_name: str) -> None:
         """
-        Delete the queue by queue_name in service bus namespace
+        Delete the queue by queue_name in service bus namespace.
 
         :param queue_name: The name of the queue or a QueueProperties with name.
         """
@@ -116,7 +158,7 @@ class AdminClientHook(BaseAzureServiceBusHook):
 
     def delete_subscription(self, subscription_name: str, topic_name: str) -> None:
         """
-        Delete a topic subscription entities under a ServiceBus Namespace
+        Delete a topic subscription entities under a ServiceBus Namespace.
 
         :param subscription_name: The subscription name that will own the rule in topic
         :param topic_name: The topic that will own the subscription rule.
@@ -132,25 +174,35 @@ class AdminClientHook(BaseAzureServiceBusHook):
 
 
 class MessageHook(BaseAzureServiceBusHook):
-    """
-    Interacts with ServiceBusClient and acts as a high level interface
-    for getting ServiceBusSender and ServiceBusReceiver.
+    """Interact with ServiceBusClient.
+
+    This acts as a high level interface for getting ServiceBusSender and ServiceBusReceiver.
     """
 
     def get_conn(self) -> ServiceBusClient:
-        """Create and returns ServiceBusClient by using the connection string in connection details"""
+        """Create and returns ServiceBusClient by using the connection string in connection details."""
         conn = self.get_connection(self.conn_id)
         connection_string: str = str(conn.schema)
+        if connection_string:
+            client = ServiceBusClient.from_connection_string(connection_string, logging_enable=True)
+        else:
+            extras = conn.extra_dejson
+            credential: str | DefaultAzureCredential = self._get_field(extras=extras, field_name="credential")
+            fully_qualified_namespace = self._get_field(extras=extras, field_name="fully_qualified_namespace")
+            if not credential:
+                credential = DefaultAzureCredential()
+            client = ServiceBusClient(
+                fully_qualified_namespace=fully_qualified_namespace,
+                credential=credential,  # type: ignore[arg-type]
+            )
 
         self.log.info("Create and returns ServiceBusClient")
-        return ServiceBusClient.from_connection_string(conn_str=connection_string, logging_enable=True)
+        return client
 
-    def send_message(
-        self, queue_name: str, messages: Union[str, List[str]], batch_message_flag: bool = False
-    ):
-        """
-        By using ServiceBusClient Send message(s) to a Service Bus Queue. By using
-        batch_message_flag it enables and send message as batch message
+    def send_message(self, queue_name: str, messages: str | list[str], batch_message_flag: bool = False):
+        """Use ServiceBusClient Send to send message(s) to a Service Bus Queue.
+
+        By using ``batch_message_flag``, it enables and send message as batch message.
 
         :param queue_name: The name of the queue or a QueueProperties with name.
         :param messages: Message which needs to be sent to the queue. It can be string or list of string.
@@ -163,37 +215,36 @@ class MessageHook(BaseAzureServiceBusHook):
             raise ValueError("Messages list cannot be empty.")
         with self.get_conn() as service_bus_client, service_bus_client.get_queue_sender(
             queue_name=queue_name
-        ) as sender:
-            with sender:
-                if isinstance(messages, str):
-                    if not batch_message_flag:
-                        msg = ServiceBusMessage(messages)
-                        sender.send_messages(msg)
-                    else:
-                        self.send_batch_message(sender, [messages])
+        ) as sender, sender:
+            if isinstance(messages, str):
+                if not batch_message_flag:
+                    msg = ServiceBusMessage(messages)
+                    sender.send_messages(msg)
                 else:
-                    if not batch_message_flag:
-                        self.send_list_messages(sender, messages)
-                    else:
-                        self.send_batch_message(sender, messages)
+                    self.send_batch_message(sender, [messages])
+            else:
+                if not batch_message_flag:
+                    self.send_list_messages(sender, messages)
+                else:
+                    self.send_batch_message(sender, messages)
 
     @staticmethod
-    def send_list_messages(sender: ServiceBusSender, messages: List[str]):
+    def send_list_messages(sender: ServiceBusSender, messages: list[str]):
         list_messages = [ServiceBusMessage(message) for message in messages]
         sender.send_messages(list_messages)  # type: ignore[arg-type]
 
     @staticmethod
-    def send_batch_message(sender: ServiceBusSender, messages: List[str]):
+    def send_batch_message(sender: ServiceBusSender, messages: list[str]):
         batch_message = sender.create_message_batch()
         for message in messages:
             batch_message.add_message(ServiceBusMessage(message))
         sender.send_messages(batch_message)
 
     def receive_message(
-        self, queue_name, max_message_count: Optional[int] = 1, max_wait_time: Optional[float] = None
+        self, queue_name, max_message_count: int | None = 1, max_wait_time: float | None = None
     ):
         """
-        Receive a batch of messages at once in a specified Queue name
+        Receive a batch of messages at once in a specified Queue name.
 
         :param queue_name: The name of the queue name or a QueueProperties with name.
         :param max_message_count: Maximum number of messages in the batch.
@@ -204,25 +255,25 @@ class MessageHook(BaseAzureServiceBusHook):
 
         with self.get_conn() as service_bus_client, service_bus_client.get_queue_receiver(
             queue_name=queue_name
-        ) as receiver:
-            with receiver:
-                received_msgs = receiver.receive_messages(
-                    max_message_count=max_message_count, max_wait_time=max_wait_time
-                )
-                for msg in received_msgs:
-                    self.log.info(msg)
-                    receiver.complete_message(msg)
+        ) as receiver, receiver:
+            received_msgs = receiver.receive_messages(
+                max_message_count=max_message_count, max_wait_time=max_wait_time
+            )
+            for msg in received_msgs:
+                self.log.info(msg)
+                receiver.complete_message(msg)
 
     def receive_subscription_message(
         self,
         topic_name: str,
         subscription_name: str,
-        max_message_count: Optional[int],
-        max_wait_time: Optional[float],
+        max_message_count: int | None,
+        max_wait_time: float | None,
     ):
-        """
-        Receive a batch of subscription message at once. This approach is optimal if you wish
-        to process multiple messages simultaneously, or perform an ad-hoc receive as a single call.
+        """Receive a batch of subscription message at once.
+
+        This approach is optimal if you wish to process multiple messages
+        simultaneously, or perform an ad-hoc receive as a single call.
 
         :param subscription_name: The subscription name that will own the rule in topic
         :param topic_name: The topic that will own the subscription rule.
@@ -240,11 +291,10 @@ class MessageHook(BaseAzureServiceBusHook):
             raise TypeError("Topic name cannot be None.")
         with self.get_conn() as service_bus_client, service_bus_client.get_subscription_receiver(
             topic_name, subscription_name
-        ) as subscription_receiver:
-            with subscription_receiver:
-                received_msgs = subscription_receiver.receive_messages(
-                    max_message_count=max_message_count, max_wait_time=max_wait_time
-                )
-                for msg in received_msgs:
-                    self.log.info(msg)
-                    subscription_receiver.complete_message(msg)
+        ) as subscription_receiver, subscription_receiver:
+            received_msgs = subscription_receiver.receive_messages(
+                max_message_count=max_message_count, max_wait_time=max_wait_time
+            )
+            for msg in received_msgs:
+                self.log.info(msg)
+                subscription_receiver.complete_message(msg)
