@@ -18,42 +18,14 @@
 from __future__ import annotations
 
 import warnings
-from functools import wraps
 from typing import IO, Any
 
 from azure.storage.file import File, FileService
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.hooks.base import BaseHook
 
 
-def _ensure_prefixes(conn_type):
-    """
-    Remove when provider min airflow version >= 2.5.0 since this is handled by
-    provider manager from that version.
-    """
-
-    def dec(func):
-        @wraps(func)
-        def inner():
-            field_behaviors = func()
-            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
-
-            def _ensure_prefix(field):
-                if field not in conn_attrs and not field.startswith("extra__"):
-                    return f"extra__{conn_type}__{field}"
-                else:
-                    return field
-
-            if "placeholders" in field_behaviors:
-                placeholders = field_behaviors["placeholders"]
-                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
-            return field_behaviors
-
-        return inner
-
-    return dec
-
-
 class AzureFileShareHook(BaseHook):
     """
     Interacts with Azure FileShare Storage.
@@ -92,7 +64,6 @@ class AzureFileShareHook(BaseHook):
         }
 
     @staticmethod
-    @_ensure_prefixes(conn_type="azure_fileshare")
     def get_ui_field_behaviour() -> dict[str, Any]:
         """Returns custom field behaviour."""
         return {
@@ -136,6 +107,11 @@ class AzureFileShareHook(BaseHook):
                 check_for_conflict(key)
             elif key.startswith(backcompat_prefix):
                 short_name = key[len(backcompat_prefix) :]
+                warnings.warn(
+                    f"`{key}` is deprecated in azure connection extra please use `{short_name}` instead",
+                    AirflowProviderDeprecationWarning,
+                    stacklevel=2,
+                )
                 if short_name not in service_options:  # prefer values provided with short name
                     service_options[short_name] = value
             else:
