@@ -17,6 +17,7 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Any, Sequence
 
 from azure.batch import models as batch_models
@@ -176,7 +177,11 @@ class AzureBatchOperator(BaseOperator):
         self.timeout = timeout
         self.should_delete_job = should_delete_job
         self.should_delete_pool = should_delete_pool
-        self.hook = self.get_hook()
+
+    @cached_property
+    def hook(self) -> AzureBatchHook:
+        """Create and return an AzureBatchHook (cached)."""
+        return self.get_hook()
 
     def _check_inputs(self) -> Any:
         if not self.os_family and not self.vm_publisher:
@@ -189,7 +194,7 @@ class AzureBatchOperator(BaseOperator):
             )
 
         if self.use_latest_image:
-            if not all(elem for elem in [self.vm_publisher, self.vm_offer]):
+            if not self.vm_publisher or not self.vm_offer:
                 raise AirflowException(
                     f"If use_latest_image_and_sku is set to True then the parameters vm_publisher, "
                     f"vm_offer, must all be set. "
